Learn R Programming

qtl2convert (version 0.30)

cross2_ril_to_genril: Convert cross2 object from ril to genril

Description

Convert a cross2 object from cross type "risibn" to cross type "genriln".

Usage

cross2_ril_to_genril(cross)

Value

The input object cross with cross type changed to class "genriln" for some value of n, and the cross information revised to match.

Arguments

cross

Object of class "cross2", as produced by qtl2::read_cross2().

Examples

Run this code
if (FALSE) {
file <- paste0("https://raw.githubusercontent.com/rqtl/",
               "qtl2data/master/CC/cc.zip")
cc <- read_cross2(file)

cc_genril <- cross2_ril_to_genril(cc)
}

if (FALSE) {
file <- paste0("https://raw.githubusercontent.com/rqtl/",
               "qtl2data/master/ArabMAGIC/arabmagic_tair9.zip")
arab <- read_cross2(file)

arab_genril <- cross2_ril_to_genril(arab)
}

Run the code above in your browser using DataLab