find_unique_geno: Find the unique genotypes for each row of a genotype matrix
Description
For genotype data (markers x individuals) on a set of individuals,
find the unique genotypes for each marker, provided that there are exactly two.
(If more than two or fewer than two, return NAs.)
Matrix with two columns. Each row corresponds to a marker,
and has the two unique genotypes, or NAs (if >2 or <2 unique
genotypes).
Arguments
genotypes
Matrix of genotypes (markers x individuals)
na.strings
Genotypes to be considered as missing values.
cores
Number of CPU cores to use, for parallel calculations.
(If 0, use parallel::detectCores().)
Alternatively, this can be links to a set of cluster sockets, as
produced by parallel::makeCluster().