Convert DOQTL genotype probabilities to R/qtl2 format
probs_doqtl_to_qtl2(
probs,
map,
is_female = NULL,
chr_column = "chr",
pos_column = "cM",
marker_column = "marker"
)An object of the form produced by qtl2::calc_genoprob().
3d array of genotype probabilities as calculated from DOQTL (individuals x genotypes x positions)
Data frame with marker map
Optional logical vector indicating which
individuals are female. Names should contain the individual
identifiers, matching the row names in probs.
Name of the column in map that contains the chromosome IDs.
Name of the column in map that contains the marker positions.
Name of the column in map that contains
the marker names. If NULL, use the row names.
We assume that the X chromosome is labeled "X" (must be
upper-case) and that any other chromosomes are autosomes.
We assume that the genotypes are labeled using the 8 letters A-H.
If the probabilities are for the full 36 states and the X
chromosome is included but is_female is not provided, we'll guess
which individuals are females based on their genotype
probabilities. (If the average, across loci, of the sum of the
heterozygote probabilities is small, we'll assume it's a female.)