Convert R/qtl2 genotype probabilities to DOQTL format
probs_qtl2_to_doqtl(probs)A single three-dimensional array, for use with DOQTL.
A "calc_genoprob" object (a list of 3d arrays of
genotype probabilities), as calculated by qtl2::calc_genoprob().
If the arrays in probs all have 8 columns, they're assumed to be
allele dosages and we paste them all together into one big array.
Otherwise, it should be that the autosomes all have 36 columns the X chromosome has 44. In this case, the male hemizygotes on the X are placed where the female homozygotes are, and then we reorder the genotypes into alphabetical order.